@@ -1,4 +1,4 @@
-from flask import jsonify, stream_with_context, Response
+from flask import jsonify
 
 """
 Lyrebird context
@@ -24,10 +24,6 @@ def make_fail_response(msg, **kwargs):
     return jsonify(fail_resp)
 
 
-def make_streamed_response(generator, code=200, mimetype='application/json'):
-    return Response(stream_with_context(generator()), mimetype=mimetype, status=code)
-
-
 # Lyrebird status contains: 'READY' and 'INITING'
 status = 'INITING'
 
