@@ -1,3 +1,4 @@
+import re
 import math
 import time
 import socket
@@ -45,6 +46,15 @@ def is_port_in_use(port, host='127.0.0.1'):
             sock.close()
 
 
+def is_target_match_patterns(pattern_list, target):
+    if not pattern_list or not target:
+        return False
+    for pattern in pattern_list:
+        if re.search(pattern, target):
+            return True
+    return False
+
+
 def find_free_port():
     with closing(socket.socket(socket.AF_INET, socket.SOCK_STREAM)) as s:
         s.bind(('', 0))
@@ -53,6 +63,11 @@ def find_free_port():
 
 
 class CaseInsensitiveDict(dict):
+
+    def __init__(self, dict):
+        for k,v in dict.items():
+            self.__setitem__(k, v)
+
     def __setitem__(self, key, value):
         super(CaseInsensitiveDict, self).__setitem__(key.lower(), value)
 
